@@ -17,8 +17,8 @@ package Dist::Zilla::Plugin::TemplateCJM;
 # ABSTRACT: Process templates, including version numbers & changes
 #---------------------------------------------------------------------
 
-our $VERSION = '4.23';
-# This file is part of Dist-Zilla-Plugin-TemplateCJM 4.23 (July 11, 2015)
+our $VERSION = '4.24';
+# This file is part of Dist-Zilla-Plugin-TemplateCJM 4.24 (October 3, 2015)
 
 
 use Moose;
@@ -286,6 +286,8 @@ sub munge_file
   if (not $version and $pmFile =~ m!^lib/(.+)\.pod$!) {
     ($dataRef->{module} = $1) =~ s!/!::!g;
     $version = $dataRef->{dist_version};
+  } else {
+    $dataRef->{module} = $pm_info->name;
   }
 
   die "ERROR: Can't find version in $pmFile" unless $version;
@@ -295,7 +297,6 @@ sub munge_file
   $self->$log_method("$pmFile: VERSION $version");
 
   $dataRef->{version} = "$version";
-  $dataRef->{module}  = $pm_info->name || $dataRef->{module};
   $dataRef->{pm_info} = \$pm_info;
   $self->_store_pathname($dataRef, $file);
 
@@ -467,8 +468,8 @@ Dist::Zilla::Plugin::TemplateCJM - Process templates, including version numbers
 
 =head1 VERSION
 
-This document describes version 4.23 of
-Dist::Zilla::Plugin::TemplateCJM, released July 11, 2015.
+This document describes version 4.24 of
+Dist::Zilla::Plugin::TemplateCJM, released October 3, 2015.
 
 =head1 SYNOPSIS
 
